# coding: utf-8

"""
    BombBomb

    We make it easy to build relationships using simple videos.

    OpenAPI spec version: 2.0.20679
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from __future__ import absolute_import

import os
import sys
import unittest

import bombbomb
from bombbomb.rest import ApiException
from bombbomb.apis.teams_api import TeamsApi


class TestTeamsApi(unittest.TestCase):
    """ TeamsApi unit test stubs """

    def setUp(self):
        self.api = bombbomb.apis.teams_api.TeamsApi()

    def tearDown(self):
        pass

    def test_cancel_jericho_send(self):
        """
        Test case for cancel_jericho_send

        Cancel a Jericho Send
        """
        pass

    def test_get_client_group_assets(self):
        """
        Test case for get_client_group_assets

        Lists team assets
        """
        pass

    def test_get_jericho_sends(self):
        """
        Test case for get_jericho_sends

        List Jericho Sends
        """
        pass

    def test_get_jericho_stats(self):
        """
        Test case for get_jericho_stats

        Gets Jericho performance statistics
        """
        pass

    def test_queue_jericho_send(self):
        """
        Test case for queue_jericho_send

        Creates a Jericho send.
        """
        pass


if __name__ == '__main__':
    unittest.main()
