# coding: utf-8

"""
    BombBomb

    We make it easy to build relationships using simple videos.

    OpenAPI spec version: 2.0.20679
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from __future__ import absolute_import

import os
import sys
import unittest

import bombbomb
from bombbomb.rest import ApiException
from bombbomb.apis.webhooks_api import WebhooksApi


class TestWebhooksApi(unittest.TestCase):
    """ WebhooksApi unit test stubs """

    def setUp(self):
        self.api = bombbomb.apis.webhooks_api.WebhooksApi()

    def tearDown(self):
        pass

    def test_add_web_hook(self):
        """
        Test case for add_web_hook

        Add Webhook
        """
        pass

    def test_delete_web_hook(self):
        """
        Test case for delete_web_hook

        Deletes Webhook
        """
        pass

    def test_get_web_hooks(self):
        """
        Test case for get_web_hooks

        Lists Webhooks
        """
        pass

    def test_send_webhook_example(self):
        """
        Test case for send_webhook_example

        Sends test Webhook
        """
        pass


if __name__ == '__main__':
    unittest.main()
